@@ -4,7 +4,9 @@
 #' @inheritParams fortify_base
 #' @return data.frame
 #' @examples
+#' \dontrun{
 #' fortify(glmnet::glmnet(data.matrix(Orange[-3]), data.matrix(Orange[3])))
+#' }
 #' @export
 fortify.glmnet <- function(model, data = NULL, ...) {
   beta <- as.matrix(model$beta)
@@ -24,7 +26,9 @@ fortify.glmnet <- function(model, data = NULL, ...) {
 #' @param ... other arguments passed to methods
 #' @return ggplot
 #' @examples
+#' \dontrun{
 #' autoplot(glmnet::glmnet(data.matrix(Orange[-3]), data.matrix(Orange[3])))
+#' }
 #' @export
 autoplot.glmnet <- function (object,
                              xvar = c("norm", "lambda", "dev"),
@@ -64,7 +68,7 @@ autoplot.glmnet <- function (object,
   label.data <- plot.data[indexer, ]
 
   # preparing plot data
-  plot.data <- tidyr::gather_(plot.data, 'variable', 'value', cols)
+  plot.data <- tidyr::gather(plot.data, 'variable', 'value', cols)
   # preparing label data (no need to gather)
   label.data$label_y <- rep(max(plot.data$value), nrow(label.data))
 
@@ -90,7 +94,9 @@ autoplot.glmnet <- function (object,
 #' @inheritParams fortify_base
 #' @return data.frame
 #' @examples
-#' fortify(glmnet::cv.glmnet(data.matrix(Orange[-3]), data.matrix(Orange[3])))
+#' if (requireNamespace("survival", quietly = TRUE)) {
+#'   fortify(glmnet::cv.glmnet(data.matrix(Orange[-3]), data.matrix(Orange[3])))
+#' }
 #' @export
 fortify.cv.glmnet <- function(model, data = NULL, ...) {
   d <- data.frame('lambda' = log(model$lambda), 'cvm' = model$cvm,
@@ -109,7 +115,9 @@ fortify.cv.glmnet <- function(model, data = NULL, ...) {
 #' @param ... other arguments passed to methods
 #' @return ggplot
 #' @examples
-#' autoplot(glmnet::cv.glmnet(data.matrix(Orange[-3]), data.matrix(Orange[3])))
+#' if (requireNamespace("survival", quietly = TRUE)) {
+#'   autoplot(glmnet::cv.glmnet(data.matrix(Orange[-3]), data.matrix(Orange[3])))
+#' }
 #' @export
 autoplot.cv.glmnet <- function (object,
                                 sign.lambda = 1,
@@ -128,7 +136,7 @@ autoplot.cv.glmnet <- function (object,
                                 label.repel = FALSE,
                                 xlim = c(NA, NA), ylim = c(NA, NA), log = "",
                                 main = NULL, xlab = NULL,
-                                ylab = 'Mean-Squared Error', asp = NULL,
+                                ylab = NULL, asp = NULL,
                                 ...) {
 
   if (is.null(xlab)) {
@@ -137,6 +145,10 @@ autoplot.cv.glmnet <- function (object,
       xlab <- paste("-", xlab, sep = "")
     }
   }
+  if (is.null(ylab)) {
+    type_measure <- object$name
+    ylab <- type_measure[[names(type_measure)[[1]]]]
+  }
   plot.data <- ggplot2::fortify(object)
   plot.data$lambda <- sign.lambda * plot.data$lambda
   plot.data$label <- rep(max(object$cvup), nrow(plot.data))
